@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2014 by Elvis Angelaccio <elvis.angelaccio@kde.org>
+    SPDX-FileCopyrightText: 2014 Elvis Angelaccio <elvis.angelaccio@kde.org>
 
-    This file is part of Kronometer.
-
-    Kronometer is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    Kronometer is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with Kronometer.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mainwindow.h"
@@ -57,7 +44,8 @@
 #include <QTableView>
 #include <QToolButton>
 
-MainWindow::MainWindow(QWidget *parent, const Session& session) : KXmlGuiWindow(parent),
+MainWindow::MainWindow(SessionModel *sessionModel, QWidget *parent, const Session& session) : KXmlGuiWindow(parent),
+    m_sessionModel {sessionModel},
     m_session {session}
 {
     Q_INIT_RESOURCE(kronometerui);
@@ -69,14 +57,12 @@ MainWindow::MainWindow(QWidget *parent, const Session& session) : KXmlGuiWindow(
     connect(m_stopwatch, &Stopwatch::paused, this, &MainWindow::slotPaused);
     connect(m_stopwatch, &Stopwatch::inactive, this, &MainWindow::slotInactive);
 
-    m_sessionModel = new SessionModel {this};
-
     setupCentralWidget();
     setupActions();
     setupGUI(ToolBar | Keys | Save | Create, QStringLiteral("kronometerui.rc"));
 
     // #351746: prevent ugly 640x480 default size (unless there is a previous size to be restored, see #361494).
-    if (not isWindowSizeSaved()) {
+    if (!isWindowSizeSaved()) {
         resize(minimumSizeHint());
     }
 
@@ -101,6 +87,11 @@ MainWindow::MainWindow(QWidget *parent, const Session& session) : KXmlGuiWindow(
     m_screensaverInterface = new QDBusInterface(QStringLiteral("org.freedesktop.ScreenSaver"),
                                                 QStringLiteral("/ScreenSaver"),
                                                 QStringLiteral("org.freedesktop.ScreenSaver"));
+        
+    if (m_startTimerImmediately) {
+        m_stopwatch->start();        
+    }
+    
 }
 
 MainWindow::~MainWindow()
@@ -165,6 +156,7 @@ void MainWindow::slotRunning()
 {
     m_session.setIsOutdated(true);
     setWindowModified(true);
+
     activateScreenInhibition();
 
     stateChanged(QStringLiteral("running"));
@@ -184,7 +176,7 @@ void MainWindow::slotPaused()
 
     // the export action can be used only if there are laps (in both the paused states).
     // so, it can't be enabled directly from kronometerui.rc
-    if (not m_lapModel->isEmpty()) {
+    if (!m_lapModel->isEmpty()) {
         m_exportAction->setEnabled(true);
     }
 }
@@ -204,7 +196,7 @@ void MainWindow::slotInactive()
 
 void MainWindow::slotPrepareForSleep(bool beforeSleep)
 {
-    if (not beforeSleep)
+    if (!beforeSleep)
         return;
 
     qDebug() << "System is going to sleep, pausing the stopwatch.";
@@ -254,17 +246,17 @@ void MainWindow::slotUpdateLapDock()
 
 void MainWindow::slotNewSession()
 {
-    auto window = new MainWindow {};
+    auto window = new MainWindow {m_sessionModel};
     window->show();
 }
 
 void MainWindow::slotOpenSession()
 {
-    auto dialog = new SessionDialog {this};
+    auto dialog = new SessionDialog {m_sessionModel, this};
 
-    connect(dialog, &QDialog::finished, this, [dialog](int result) {
+    connect(dialog, &QDialog::finished, this, [this, dialog](int result) {
         if (result == QDialog::Accepted) {
-            auto window = new MainWindow {nullptr, dialog->selectedSession()};
+            auto window = new MainWindow {m_sessionModel, nullptr, dialog->selectedSession()};
             window->show();
         }
         dialog->deleteLater();
@@ -275,7 +267,7 @@ void MainWindow::slotOpenSession()
 
 void MainWindow::slotSaveSession()
 {
-    if (not m_session.isOutdated())
+    if (!m_session.isOutdated())
         return;
 
     m_session.clear();    // required for laps consistency
@@ -301,7 +293,7 @@ void MainWindow::slotSaveSessionAs()
                                       {},
                                       &accepted);
 
-    if (not accepted)
+    if (!accepted)
         return;
 
     if (name.isEmpty())
@@ -314,7 +306,7 @@ void MainWindow::slotExportLapsAs()
 {
     auto dialog = new QFileDialog {this};
     dialog->setAcceptMode(QFileDialog::AcceptSave);
-    dialog->setConfirmOverwrite(true);
+    dialog->setOption(QFileDialog::DontConfirmOverwrite, false);
     dialog->setWindowTitle(i18nc("@title:window", "Export Laps"));
     dialog->setMimeTypeFilters({ QStringLiteral("text/csv"), QStringLiteral("application/json") });
 
@@ -350,7 +342,7 @@ void MainWindow::slotToggleMenuBar()
 void MainWindow::slotUpdateControlMenu()
 {
     auto menu = qobject_cast<QMenu*>(sender());
-    if (not menu)
+    if (!menu)
         return;
 
     // All actions get cleared by QMenu::clear().
@@ -508,11 +500,13 @@ void MainWindow::loadSettings()
     auto timeFormat = TimeFormat {KronometerConfig::showHours(), KronometerConfig::showMinutes(), timeFrac};
     auto lapTimeFormat = TimeFormat {KronometerConfig::showLapHours(), KronometerConfig::showLapMinutes(), lapFrac};
 
+    m_startTimerImmediately = KronometerConfig::startTimerImmediately();
+
     m_lapAction->setVisible(KronometerConfig::isLapsRecordingEnabled());
     m_exportAction->setVisible(KronometerConfig::isLapsRecordingEnabled());
     m_lapView->setVisible(KronometerConfig::isLapsRecordingEnabled());
-    m_lapView->setColumnHidden(m_lapModel->columnForRole(LapModel::Roles::AbsoluteTimeRole), not KronometerConfig::showLapAbsoluteTimes());
-    m_lapView->setColumnHidden(m_lapModel->columnForRole(LapModel::Roles::NoteRole), not KronometerConfig::showLapNotes());
+    m_lapView->setColumnHidden(m_lapModel->columnForRole(LapModel::Roles::AbsoluteTimeRole), !KronometerConfig::showLapAbsoluteTimes());
+    m_lapView->setColumnHidden(m_lapModel->columnForRole(LapModel::Roles::NoteRole), !KronometerConfig::showLapNotes());
     m_lapModel->setTimeFormat(lapTimeFormat);
     timeFormat.showDividers(false);
     m_stopwatchDisplay->setTimeFormat(timeFormat);
@@ -538,7 +532,7 @@ void MainWindow::loadSettings()
 
 void MainWindow::setupGranularity()
 {
-    if (not KronometerConfig::showSecondFractions()) {
+    if (!KronometerConfig::showSecondFractions()) {
         m_stopwatch->setGranularity(Stopwatch::Granularity::Seconds);
         return;
     }
@@ -597,7 +591,7 @@ void MainWindow::exportLapsAs(const QString& name, const QString& mimeType)
     auto exportName = name;
 
     if (mimeType == QLatin1String("application/json")) {
-        if (not exportName.endsWith(QLatin1String(".json"))) {
+        if (!exportName.endsWith(QLatin1String(".json"))) {
             exportName += QLatin1String(".json");
         }
 
@@ -612,7 +606,7 @@ void MainWindow::exportLapsAs(const QString& name, const QString& mimeType)
         exportFile.commit();
     }
     else if (mimeType == QLatin1String("text/csv")) {
-        if (not exportName.endsWith(QLatin1String(".csv"))) {
+        if (!exportName.endsWith(QLatin1String(".csv"))) {
             exportName += QLatin1String(".csv");
         }
 
@@ -661,7 +655,7 @@ bool MainWindow::isWindowSizeSaved() const
     const auto keys = group.keyList();
     for (const auto& key : keys) {
         // Size keys contain the screen size, e.g. 'Width 1920' and 'Height 1080'.
-        if (key.startsWith(QLatin1String("Height")) or key.startsWith(QLatin1String("Width"))) {
+        if (key.startsWith(QLatin1String("Height")) || key.startsWith(QLatin1String("Width"))) {
             return true;
         }
     }
@@ -673,12 +667,14 @@ QString MainWindow::timestampMessage()
 {
     const auto timestamp = QDateTime::currentDateTime();
 
-    return i18nc("@info:shell", "Created by Kronometer on %1", timestamp.toString(Qt::DefaultLocaleLongDate));
+    const QString timeString = QLocale::system().toString(timestamp, QLocale::LongFormat);
+
+    return i18nc("@info:shell", "Created by Kronometer on %1", timeString);
 }
 
 void MainWindow::createControlMenuButton()
 {
-    if (not m_controlMenuButton.isNull()) {
+    if (!m_controlMenuButton.isNull()) {
         return;
     }
 
@@ -715,7 +711,7 @@ void MainWindow::deleteControlMenuButton()
 
 bool MainWindow::addActionToMenu(QAction *action, QMenu *menu)
 {
-    if (not action or not menu)
+    if (!action || !menu)
         return false;
 
     const auto toolBarWidget = toolBar();
